aboutsummaryrefslogtreecommitdiff
path: root/id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java
diff options
context:
space:
mode:
Diffstat (limited to 'id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java')
-rw-r--r--id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java40
1 files changed, 30 insertions, 10 deletions
diff --git a/id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java b/id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java
index aac1dc422..65fe9047d 100644
--- a/id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java
+++ b/id.server/src/at/gv/egovernment/moa/id/data/AuthenticationData.java
@@ -31,14 +31,18 @@ public class AuthenticationData {
*/
private String issueInstant;
/**
- * user identification (ZMR-Zahl); <code>null</code>,
+ * user identification value (Stammzahl); <code>null</code>,
* if the authentication module is configured not to return this data
*/
private String identificationValue;
+ /**
+ * user identification type
+ */
+ private String identificationType;
/**
* application specific user identifier (VPK)
*/
- private String vpk;
+ private String bPK;
/**
* given name of the user
*/
@@ -112,11 +116,11 @@ public class AuthenticationData {
}
/**
- * Returns the vpk.
+ * Returns the bPK.
* @return String
*/
- public String getVPK() {
- return vpk;
+ public String getPBK() {
+ return bPK;
}
/**
@@ -152,11 +156,11 @@ public class AuthenticationData {
}
/**
* Sets the vpk.
* @param vpk The vpk to set
*/
- public void setVPK(String vpk) {
- this.vpk = vpk;
+ public void setPBK(String bPK) {
+ this.bPK = bPK;
}
/**
@@ -199,6 +203,14 @@ public class AuthenticationData {
return identificationValue;
}
+ /**
+ * Returns the identificationType
+ * @return String
+ */
+ public String getIdentificationType() {
+ return identificationType;
+ }
+
/**
* Returns the issueInstant.
* @return String
@@ -263,6 +275,14 @@ public class AuthenticationData {
this.identificationValue = identificationValue;
}
+ /**
+ * Sets the identificationType.
+ * @param identificationType The identificationType to set
+ */
+ public void setIdentificationType(String identificationType) {
+ this.identificationType = identificationType;
+ }
+
/**
* Sets the issueInstant.
* @param issueInstant The issueInstant to set
@@ -31,14 +31,18 @@ public class AuthenticationData {
/**
- * application specific user identifier (VPK)
+ * application specific user identifier (bPK)
*/
@@ -152,11 +156,11 @@ public class AuthenticationData {
}
/**
- * Sets the vpk.
- * @param vpk The vpk to set
+ * Sets the bPK.
+ * @param bPK The bPK to set
*/